/* eslint-disable vue/no-reserved-component-names */
/* eslint-disable vue/multi-word-component-names */
import './assets/main.scss'

import { createApp } from 'vue'
import { createPinia } from 'pinia'
import axios, { Axios, type AxiosInstance } from 'axios'

import Aura from '@primeuix/themes/aura'
import Button from 'primevue/button'
import Card from 'primevue/card'
import Chip from 'primevue/chip'
import Menubar from 'primevue/menubar'
import PrimeVue from 'primevue/config'
import Toast from 'primevue/toast'
import ToastService from 'primevue/toastservice'

import App from './App.vue'
import router from './router'

const app = createApp(App)

app.use(createPinia())
app.use(router)
app.use(PrimeVue, {
  theme: {
    preset: Aura
  }
})
app.use(ToastService)
app.component('Button', Button)
app.component('Menubar', Menubar)
app.component('Card', Card)
app.component('Chip', Chip)
app.component('Toast', Toast)

interface Settings {
  apiUrl: string
}

export let settings: Settings
export let apiServer: AxiosInstance

export interface TaskDefault {
  schedule_timeout: number
  execution_timeout: number
  priority: number
  retries: number
  backoff_factor: number
  backoff_max_seconds: number
}

export interface Workflow {
  name: string
  description: string
  version: string
  on_events: string[]
  on_crons: string[]
  concurrency: number
  input_validator: string
  default_priority: number
  task_defaults: TaskDefault
}

export interface Workflows {
  [name: string]: Workflow
}

// The settings.json file is expected at the server's base url
axios.get("settings.json").then().then(
  resp => {
    settings = resp.data
    apiServer = axios.create({
      baseURL: settings.apiUrl,
      timeout: 10000
    })
    // Really start when apiServer is available
    app.mount('#app')
  }
).catch(err => alert("Cannot load settings"))